'use strict';

var _tape = require('tape');

var _tape2 = _interopRequireDefault(_tape);

var _readPixel = require('../read-pixel');

var _readPixel2 = _interopRequireDefault(_readPixel);

var _mesh = require('../../../lib/mesh');

var _mesh2 = _interopRequireDefault(_mesh);

var _perspective = require('../../../lib/camera/perspective');

var _perspective2 = _interopRequireDefault(_perspective);

var _flat = require('../../../lib/material/flat');

var _flat2 = _interopRequireDefault(_flat);

var _fog = require('../../../lib/material/augment/fog');

var _fog2 = _interopRequireDefault(_fog);

var _forward = require('../../../lib/renderer/forward');

var _forward2 = _interopRequireDefault(_forward);

var _scene = require('../../../lib/scene');

var _scene2 = _interopRequireDefault(_scene);

var _geometry = require('../../../lib/geometry');

var _geometry2 = _interopRequireDefault(_geometry);

var _geo3dBox = require('geo-3d-box');

var _geo3dBox2 = _interopRequireDefault(_geo3dBox);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _tape2.default)("Fog Augmentation", function (t) {

	var scene = (0, _scene2.default)({
		renderer: (0, _forward2.default)({
			autoResizeCanvas: false,
			width: 100,
			height: 100
		})
	});
	var gl = scene.renderer.gl;
	var camera = (0, _perspective2.default)();
	var geometry = (0, _geometry2.default)((0, _geo3dBox2.default)({ size: 5 }));
	var mesh;
	camera.transform.position[2] = 20;

	t.test("the red box is affected by dark fog", function (t) {
		t.plan(3);

		var material = (0, _fog2.default)((0, _flat2.default)({ color: [1, 0, 0] }), {
			near: 10,
			far: 30,
			color: [0, 0, 0]
		});
		mesh = (0, _mesh2.default)(material, geometry);
		mesh.transform.euler[1] = Math.PI * 0.25;
		scene.add(mesh);
		scene.render(camera);

		t.deepLooseEqual((0, _readPixel2.default)(gl, 50, 50), [169, 0, 0], "The center is mostly red");
		t.deepLooseEqual((0, _readPixel2.default)(gl, 35, 50), [139, 0, 0], "The left is darker");
		t.deepLooseEqual((0, _readPixel2.default)(gl, 65, 50), [137, 0, 0], "The right is darker");
	});

	t.test("the red box is affected by light fog", function (t) {
		t.plan(3);

		mesh.material.shading.fog.color = [1, 1, 1];
		scene.render(camera);

		t.deepLooseEqual((0, _readPixel2.default)(gl, 50, 50), [255, 86, 86], "The center is mostly red");
		t.deepLooseEqual((0, _readPixel2.default)(gl, 35, 50), [255, 116, 116], "The left is lighter");
		t.deepLooseEqual((0, _readPixel2.default)(gl, 65, 50), [255, 118, 118], "The right is darker");

		scene.renderer.destroy();
	});
});